@@ -50,7 +50,6 @@ static void basep_pos_class_init (BasePPosClass *klass);
 static void basep_pos_instance_init (BasePPos *pos);
 
 /* Forward declare some static functions for use in the class init */
-static void basep_widget_move_focus_out (BasePWidget *basep);
 static void basep_widget_mode_change (BasePWidget *basep, BasePMode mode);
 static void basep_widget_state_change (BasePWidget *basep, BasePState state);
 static void basep_widget_real_screen_change (BasePWidget *basep, int screen);
@@ -60,9 +59,10 @@ static void basep_widget_realize (GtkWidget *w);
 static void basep_widget_map (GtkWidget *w);
 static gboolean basep_enter_notify (GtkWidget *widget, GdkEventCrossing *event);
 static gboolean basep_leave_notify (GtkWidget *widget, GdkEventCrossing *event);
-static gboolean basep_key_press (GtkWidget *widget, GdkEventKey *event);
 static void basep_style_set (GtkWidget *widget, GtkStyle *previous_style);
 static void basep_widget_destroy (GtkObject *o);
+static int  basep_widget_focus_in_event (GtkWidget     *widget,
+					 GdkEventFocus *event);
 
 static void basep_widget_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static void basep_widget_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
@@ -124,14 +124,12 @@ static guint basep_widget_signals[WIDGET_LAST_SIGNAL] = { 0 };
 static void
 basep_widget_class_init (BasePWidgetClass *klass)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS (klass);
-	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-	GtkBindingSet *binding_set;
+	GObjectClass   *object_class = (GObjectClass *) klass;
+	GtkObjectClass *gtk_object_class = (GtkObjectClass *) klass;
+	GtkWidgetClass *widget_class = (GtkWidgetClass *) klass;
 	
 	basep_widget_parent_class = g_type_class_ref (gtk_window_get_type ());
 
-	klass->move_focus_out = basep_widget_move_focus_out;
 	klass->mode_change = basep_widget_mode_change;
 	klass->state_change = basep_widget_state_change;
 	klass->screen_change = basep_widget_real_screen_change;
@@ -142,7 +140,7 @@ basep_widget_class_init (BasePWidgetClass *klass)
 	widget_class->map = basep_widget_map;
 	widget_class->enter_notify_event = basep_enter_notify;
 	widget_class->leave_notify_event = basep_leave_notify;
-	widget_class->key_press_event = basep_key_press;
+	widget_class->focus_in_event = basep_widget_focus_in_event;
 	widget_class->style_set = basep_style_set;
 
 	gtk_object_class->destroy = basep_widget_destroy;
@@ -153,16 +151,16 @@ basep_widget_class_init (BasePWidgetClass *klass)
         g_object_class_install_property (object_class,
                                         PROP_MODE,
                                         g_param_spec_enum ("mode",
-                                                             _("mode"),
-                                                             _("mode"),
+                                                             _("Mode"),
+                                                             _("Mode of this panel"),
 							    PANEL_TYPE_BASE_PMODE,
                                                             BASEP_EXPLICIT_HIDE,
                                                             G_PARAM_READWRITE));
         g_object_class_install_property (object_class,
                                         PROP_STATE,
                                         g_param_spec_enum ("state",
-                                                             _("state"),
-                                                             _("state"),
+                                                             _("State"),
+                                                             _("Current state of this panel"),
 							     PANEL_TYPE_BASE_PSTATE,
                                                              BASEP_SHOWN,
                                                              G_PARAM_READWRITE));
@@ -170,16 +168,16 @@ basep_widget_class_init (BasePWidgetClass *klass)
         g_object_class_install_property (object_class,
         			  	PROP_HIDEBUTTONS_ENABLED,
                                         g_param_spec_boolean ("hidebuttons_enabled",
-                                                             _("hidebuttons_enabled"),
-                                                             _("hidebuttons_enabled"),
+                                                             _("Hidebuttons enabled"),
+                                                             _("Are hidebuttons (buttons that hide or show the panel) enabled?"),
                                                              TRUE,
                                                              G_PARAM_READWRITE));
 
         g_object_class_install_property (object_class,
         			  	PROP_HIDEBUTTON_PIXMAPS_ENABLED,
                                         g_param_spec_boolean ("hidebutton_pixmaps_enabled",
-                                                             _("hidebutton_pixmaps_enabled"),
-                                                             _("hidebutton_pixmaps_enabled"),
+                                                             _("Hidebutton pixmaps enabled"),
+                                                             _("Hidebuttons have pixmaps"),
                                                              TRUE,
                                                              G_PARAM_READWRITE));
 
@@ -195,17 +193,6 @@ basep_widget_class_init (BasePWidgetClass *klass)
 			      1,
 			      PANEL_TYPE_OBJECT_TYPE); */
 
-	basep_widget_signals[MOVE_FOCUS_OUT_SIGNAL] = 
-		g_signal_new	("move_focus_out",
-				G_TYPE_FROM_CLASS (object_class),
-				G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-				G_STRUCT_OFFSET (BasePWidgetClass, move_focus_out),
-				NULL,
-				NULL,
-				panel_marshal_VOID__VOID,
-				G_TYPE_NONE,
-				0);
-
 	basep_widget_signals[MODE_CHANGE_SIGNAL] = 
 		g_signal_new	("mode_change",
 			       	G_TYPE_FROM_CLASS (object_class),
@@ -241,14 +228,6 @@ basep_widget_class_init (BasePWidgetClass *klass)
 				G_TYPE_NONE,
 				1,
 				G_TYPE_INT);
-
-	binding_set = gtk_binding_set_by_class (gtk_object_class);
-	gtk_binding_entry_add_signal (binding_set,
-				      GDK_Tab, GDK_CONTROL_MASK,
-				      "move_focus_out", 0);
-	gtk_binding_entry_add_signal (binding_set,
-				      GDK_KP_Tab, GDK_CONTROL_MASK,
-				      "move_focus_out", 0);
 }
 
 static void
@@ -555,26 +534,6 @@ basep_widget_size_allocate (GtkWidget *widget,
 	}
 }
 
-static void
-basep_widget_move_focus_out (BasePWidget *basep)
-{
-	if (DRAWER_IS_WIDGET (basep)) {
-		Drawer *drawer = g_object_get_data (G_OBJECT (basep),
-               		                             DRAWER_PANEL_KEY);
-		PanelWidget *panel = PANEL_WIDGET (drawer->button->parent);
-		GtkWidget *parent = panel->panel_parent;
-
-		drawer_widget_close_drawer (DRAWER_WIDGET (basep), parent);
-		drawer->moving_focus = TRUE;
-		gtk_window_present (GTK_WINDOW (parent));
-		gtk_widget_grab_focus (drawer->button);
-	} else {
-		PanelWidget *panel = PANEL_WIDGET (basep->panel);
-
-		panel_widget_focus (panel);
-	}
-}
-
 static void
 basep_widget_mode_change (BasePWidget *basep, BasePMode old_mode)
 {
@@ -809,8 +768,6 @@ basep_pos_get_hide_pos (BasePWidget *basep,
 static void
 basep_pos_class_init (BasePPosClass *klass)
 {
-	/*GtkObjectClass *object_class = GTK_OBJECT_CLASS(klass);*/
-
 	basep_pos_parent_class = g_type_class_ref (gtk_object_get_type ());
 
 	klass->get_hide_size = basep_pos_get_hide_size;
@@ -824,24 +781,18 @@ basep_pos_instance_init (BasePPos *pos)
 	return;
 }
 
-static gboolean 
-basep_key_press (GtkWidget *widget, GdkEventKey *event)
+static int
+basep_widget_focus_in_event (GtkWidget     *widget,
+			     GdkEventFocus *event)
 {
-	BasePWidget *basep;
-	PanelWidget *panel;
+	BasePWidget *basep = BASEP_WIDGET (widget);
 
-	g_return_val_if_fail (BASEP_IS_WIDGET (widget), FALSE);
+	if (basep->state == BASEP_AUTO_HIDDEN)
+		basep_widget_autoshow (basep);
 
-	basep = BASEP_WIDGET (widget);
-
-	g_return_val_if_fail (PANEL_IS_WIDGET (basep->panel), FALSE);
-
-	panel = PANEL_WIDGET (basep->panel);
-	
-	panel_widget_save_key_event (panel, event);
-	return GTK_WIDGET_CLASS (basep_widget_parent_class)->key_press_event (widget, event);
+	return GTK_WIDGET_CLASS (basep_widget_parent_class)->focus_in_event (widget, event);
 }
- 
+
 static gboolean
 basep_leave_notify (GtkWidget *widget,
 		    GdkEventCrossing *event)
@@ -1064,8 +1015,7 @@ basep_widget_do_hiding(BasePWidget *basep, PanelOrient hide_orient,
 			y = move_step(oy,dy,start_time,end_time,cur_time);
 			w = move_step(ow,dw,start_time,end_time,cur_time);
 			h = move_step(oh,dh,start_time,end_time,cur_time);
-			gdk_window_move_resize(wid->window, x,y,w,h);
-			gdk_flush();
+			xstuff_set_pos_size (wid->window, x, y, w, h);
 			g_usleep (1000);
 		}
 
@@ -1183,12 +1133,13 @@ basep_widget_do_showing(BasePWidget *basep, PanelOrient hide_orient,
 			y = move_step(oy,dy,start_time,end_time,cur_time);
 			w = move_step(ow,dw,start_time,end_time,cur_time);
 			h = move_step(oh,dh,start_time,end_time,cur_time);
-			gdk_window_move_resize(wid->window, x,y,w,h);
-			gdk_flush();
+			xstuff_set_pos_size (wid->window, x, y, w, h);
 			
 			/*drawing the entire table flickers, so don't
 			  do it often*/
 			/* FIXME: does it still flicker? */
+			/* FIXME: sometimes this updates, sometimes it doesn't
+			 * see bug #81654 */
 			if (i++ % 10) {
 				/* FIXME: is invalidation needed, and if so it should only be
 				 * partial */
