@@ -10,6 +10,7 @@
 #include "button-widget.h"
 #include "panel-widget.h"
 #include "basep-widget.h"
+#include "panel-main.h"
 #include "panel-types.h"
 #include "panel-util.h"
 #include "panel-config-global.h"
@@ -97,8 +98,8 @@ translate_to(GtkWidget *from, GtkWidget *to, int *x, int *y)
 {
 	while (from != to) {
 		if (!GTK_WIDGET_NO_WINDOW (from)) {
-			*x += from->allocation.x;
-			*y += from->allocation.y;
+			*x += MAX (from->allocation.x, 0);
+			*y += MAX (from->allocation.y, 0);
 		}
 		from = from->parent;
 	}
@@ -141,7 +142,8 @@ calculate_overlay_geometry (PanelWidget *panel,
 		/* we use the requisition, since allocation might have not
 		   yet happened if we are inside the allocation, anyway
 		   they are the same for basep */
-		*h = parent->requisition.height;
+		if(*h < parent->requisition.height)
+			*h = parent->requisition.height;
 
 		if ((*w + applet->allocation.x) > panel->size) {
 			*w = panel->size - applet->allocation.x;
@@ -171,7 +173,8 @@ calculate_overlay_geometry (PanelWidget *panel,
 		}
 
 		*x = 0;
-		*w = parent->requisition.width;
+		if(*w < parent->requisition.width)
+			*w = parent->requisition.width;
 
 		if ((*h + applet->allocation.y) > panel->size) {
 			*h = panel->size - applet->allocation.y;
@@ -305,7 +308,8 @@ loadup_file(const char *file)
 		return NULL;
 
 	if ( ! g_path_is_absolute (file)) {
-		char *full = gnome_desktop_item_find_icon (file,
+		char *full = gnome_desktop_item_find_icon (panel_icon_loader,
+							   file,
 							   48 /* desired size */,
 							   0 /* flags */);
 
@@ -440,11 +444,11 @@ button_widget_expose (GtkWidget         *widget,
 	off = (button->in_button && button->button_down) ?
 		SCALE(BUTTON_WIDGET_DISPLACEMENT) : 0;
 	
-	if (!global_config.highlight_when_over || !button->in_button) {
-		pb = button_widget->scaled;
-	} else {
+	if (global_config.highlight_when_over && 
+	    (button->in_button || GTK_WIDGET_HAS_FOCUS (widget)))
 		pb = button_widget->scaled_hc;
-	}
+	else
+		pb = button_widget->scaled;
 	
 	w = gdk_pixbuf_get_width (pb);
 	h = gdk_pixbuf_get_height (pb);
@@ -491,13 +495,21 @@ button_widget_expose (GtkWidget         *widget,
 	}
 
 	if (GTK_WIDGET_HAS_FOCUS (widget)) {
+		gint focus_width, focus_pad;
+		gint x, y, width, height;
+
+		gtk_widget_style_get (widget,
+				      "focus-line-width", &focus_width,
+				      "focus-padding", &focus_pad,
+				      NULL);
+		x = widget->allocation.x + focus_pad;
+		y = widget->allocation.y + focus_pad;
+		width = widget->allocation.width -  (focus_width + 2 * focus_pad); focus_pad;
+		height = widget->allocation.height -  (focus_width + 2 * focus_pad); focus_pad;
 		gtk_paint_focus (widget->style, widget->window,
 				 GTK_WIDGET_STATE (widget),
 				 &event->area, widget, "button",
-				 widget->allocation.x + 1,
-				 widget->allocation.y + 1,
-				 widget->allocation.width - 3,
-				 widget->allocation.height - 3);
+				 x, y, width, height);
 	}
 	
 	return FALSE;
