@@ -32,6 +32,7 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 
@@ -51,6 +52,7 @@
 #include "menu-fentry.h"
 #include "menu.h"
 #include "multiscreen-stuff.h"
+#include "panel-main.h"
 #include "panel-util.h"
 #include "panel-gconf.h"
 
@@ -79,7 +81,7 @@ extern GtkTooltips *panel_tooltips;
 extern gboolean no_run_box;
 
 static GtkWidget *run_dialog = NULL;
-static GSList *add_icon_iters = NULL;
+static GSList *add_icon_paths = NULL;
 static guint add_icon_idle_id = 0;
 static guint add_items_idle_id = 0;
 static guint find_icon_timeout_id = 0;
@@ -454,7 +456,7 @@ run_dialog_response (GtkWidget *w, int response, gpointer data)
 				panel_error_dialog ("run_error",
 						    _("<b>Failed to open file:</b> '%s'\n\nDetails: %s"),
 						    escaped, error->message);
-				g_error_free (error);
+				g_clear_error (&error);
 			}
 	
 			gnome_vfs_file_info_unref (info);
@@ -781,7 +783,7 @@ drag_data_received (GtkWidget        *widget,
 		    guint32           time,
 		    gpointer          data)
 {
-	GtkEntry *entry = data;
+	GtkWidget *entry = data;
 	char **uris;
 	int i;
 
@@ -998,7 +1000,7 @@ find_icon_timeout (gpointer data)
 	GtkTreeModel *model;
 	GtkTreePath *path;
 	GtkWidget *pixmap;
-	GValue value;
+	GValue value = {0};
 	char *exec, *icon;
 	char *found_icon = NULL;
 
@@ -1061,7 +1063,8 @@ find_icon_timeout (gpointer data)
 
 	pixbuf = NULL;
 	if (found_icon != NULL) {
-		icon = gnome_desktop_item_find_icon (found_icon,
+		icon = gnome_desktop_item_find_icon (panel_icon_loader,
+                                                     found_icon,
 						     48 /* desired size */,
 						     0 /* flags */);
 		if (icon != NULL) {
@@ -1084,36 +1087,44 @@ find_icon_timeout (gpointer data)
 static gboolean
 add_icon_idle (GtkListStore *list)
 {
-	GtkTreeIter *iter;
+	GtkTreeIter  iter;
+	GtkTreePath *path;
 	gboolean     long_operation = FALSE;
 	GdkPixbuf   *pixbuf;
 	char        *file;
 
 	do {
-		if (!add_icon_iters) {
+		if (add_icon_paths == NULL) {
 			add_icon_idle_id = 0;
 			return FALSE;
 		}
 
-		iter = add_icon_iters->data;
-		add_icon_iters = g_slist_remove (add_icon_iters, iter);
+		path = add_icon_paths->data;
+		add_icon_paths->data = NULL;
+		add_icon_paths = g_slist_delete_link (add_icon_paths,
+						      add_icon_paths);
 
-		gtk_tree_model_get (GTK_TREE_MODEL (list), iter,
+		if ( ! gtk_tree_model_get_iter (GTK_TREE_MODEL (list),
+						&iter,
+						path)) {
+			gtk_tree_path_free (path);
+			continue;
+		}
+		gtk_tree_path_free (path);
+
+		gtk_tree_model_get (GTK_TREE_MODEL (list), &iter,
 				    COLUMN_ICON_FILE, &file, -1);
 
 		pixbuf = panel_make_menu_icon (file, NULL /* fallback */,
 					       ICON_SIZE, &long_operation);
 		if (pixbuf) {
-			gtk_list_store_set (list, iter, COLUMN_ICON, pixbuf, -1);
+			gtk_list_store_set (list, &iter, COLUMN_ICON, pixbuf, -1);
 			g_object_unref (pixbuf);
 		}
-
-		g_free (iter);
-
 	/* don't go back into the main loop if this wasn't very hard to do */
 	} while (!long_operation);
 
-	if (!add_icon_iters) {
+	if (add_icon_paths == NULL) {
 		add_icon_idle_id = 0;
 		return FALSE;
 	}
@@ -1160,10 +1171,9 @@ fill_list (GtkWidget *list)
 
 		fr = tmp->data;
 		if (prev_name && strcmp (fr->fullname, prev_name) == 0) {
-			GSList *del = tmp;
-
-			prev->next = del->next;
-			g_slist_free_1 (del);
+			prev->next = tmp->next;
+			tmp->data = NULL;
+			g_slist_free_1 (tmp);
 			tmp = prev->next;
 		} else {
 			prev = tmp;
@@ -1174,15 +1184,14 @@ fill_list (GtkWidget *list)
 
 	tmp = files;
 	while (tmp != NULL) {
-		GtkTreeIter *iter;
+		GtkTreeIter iter;
 		FileRec *fr;
+		GtkTreePath *path;
 
 		fr = tmp->data;
 
-		iter = g_new0 (GtkTreeIter, 1);
-
-		gtk_list_store_append (store, iter);
-		gtk_list_store_set (store, iter,
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
 				    COLUMN_ICON, NULL,
 				    COLUMN_ICON_FILE, fr->icon,
 				    COLUMN_FULLNAME, fr->fullname,
@@ -1191,7 +1200,10 @@ fill_list (GtkWidget *list)
 				    COLUMN_EXEC, fr->exec,
 				    -1);
 
-		add_icon_iters = g_slist_prepend (add_icon_iters, iter);
+		path = gtk_tree_model_get_path (GTK_TREE_MODEL (store), &iter);
+
+		if (path != NULL)
+			add_icon_paths = g_slist_prepend (add_icon_paths, path);
 
 		tmp = tmp->next;
 	}
@@ -1203,7 +1215,7 @@ fill_list (GtkWidget *list)
 
 	add_columns (GTK_TREE_VIEW (list));
 
-	add_icon_iters = g_slist_reverse (add_icon_iters);
+	add_icon_paths = g_slist_reverse (add_icon_paths);
 
 	if (add_icon_idle_id == 0)
 		add_icon_idle_id =
@@ -1263,19 +1275,20 @@ unset_selected (GtkWidget *dialog)
                 char *msg;
                 msg = g_strdup_printf (_("Will run command: '%s'"),
                                        text);
-                if (desc_label)
+                if (desc_label != NULL)
                         gtk_label_set_text (GTK_LABEL (desc_label), msg);
 
                 g_free (msg);
         } else {
                 
-                if (desc_label)
+                if (desc_label != NULL)
                         gtk_label_set_text (GTK_LABEL (desc_label), _("No application selected"));
         }
 
         g_free (text);
         
-        unset_pixmap (gpixmap);
+	if (gpixmap != NULL)
+		unset_pixmap (gpixmap);
 
         g_object_set_data (G_OBJECT (dialog), "use_list",
 			   GPOINTER_TO_INT (FALSE));
@@ -1322,7 +1335,7 @@ selection_changed (GtkTreeSelection *selection,
         gpixmap = g_object_get_data (G_OBJECT (dialog), "pixmap");
         desc_label = g_object_get_data (G_OBJECT (dialog), "desc_label");
 
-        if (name != NULL) {
+        if (name != NULL && gpixmap != NULL) {
                 QuickDesktopItem *qitem;
 
 		qitem = quick_desktop_item_load_uri (name /*file */,
@@ -1336,7 +1349,8 @@ selection_changed (GtkTreeSelection *selection,
 				gtk_label_set_text (GTK_LABEL (desc_label),
 						    sure_string (qitem->comment));
 
-			icon = gnome_desktop_item_find_icon (qitem->icon,
+			icon = gnome_desktop_item_find_icon (panel_icon_loader,
+                                                             qitem->icon,
 							     48 /* desired size */,
 							     0 /* flags */);
 			if (icon != NULL) {
@@ -1504,9 +1518,9 @@ run_dialog_destroyed (GtkWidget *widget)
 {
 	run_dialog = NULL;
 
-	g_slist_foreach (add_icon_iters, (GFunc)g_free, NULL);
-	g_slist_free (add_icon_iters);
-	add_icon_iters = NULL;
+	g_slist_foreach (add_icon_paths, (GFunc)gtk_tree_path_free, NULL);
+	g_slist_free (add_icon_paths);
+	add_icon_paths = NULL;
 
 	if (add_icon_idle_id)
 		g_source_remove (add_icon_idle_id);
@@ -1534,6 +1548,9 @@ show_run_dialog (void)
 
 	if (run_dialog != NULL) {
 		gtk_window_present (GTK_WINDOW (run_dialog));
+		/* always focus the entry initially */
+		w = g_object_get_data (G_OBJECT (run_dialog), "entry");
+		gtk_widget_grab_focus (w);
 		return;
 	}
 
@@ -1592,6 +1609,10 @@ show_run_dialog (void)
 			 		 w, NULL);
 	}
 
+	/* always focus the entry initially */
+	w = g_object_get_data (G_OBJECT (run_dialog), "entry");
+	gtk_widget_grab_focus (w);
+
 	gtk_widget_show_all (run_dialog);
 }
 
