@@ -15,6 +15,8 @@
 #include <sys/stat.h>
 #include <sys/wait.h>
 
+#include <gdk/gdkkeysyms.h>
+
 #include <libgnome/libgnome.h>
 #include <libbonobo.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
@@ -44,7 +46,6 @@
 #include "panel-config-global.h"
 #include "panel-gconf.h"
 #include "session.h"
-#include "status.h"
 #include "panel-applet-frame.h"
 #include "global-keys.h"
 
@@ -211,15 +212,6 @@ orientation_change (AppletInfo  *info,
 				       (gpointer)basep->panel);
 		}
 		break;
-	case APPLET_STATUS: {
-		StatusApplet *status = info->data;
-
-		if (status->orient != panel->orient) {
-			status->orient = panel->orient;
-			status_applet_update (status);
-		}
-		}
-		break;
 	default:
 		break;
 	}
@@ -271,24 +263,9 @@ void
 size_change (AppletInfo  *info,
 	     PanelWidget *panel)
 {
-	PanelSize size = panel->sz;
-	
-	switch (info->type) {
-	case APPLET_BONOBO:
+	if (info->type == APPLET_BONOBO)
 		panel_applet_frame_change_size (
-			PANEL_APPLET_FRAME (info->widget), size);
-		break;
-	case APPLET_STATUS: {
-		StatusApplet *status = info->data;
-
-		status->size = size;
-
-		status_applet_update (status);
-		}
-		break;
-	default:
-		break;
-	}
+			PANEL_APPLET_FRAME (info->widget), panel->sz);
 }
 
 static void
@@ -808,9 +785,6 @@ panel_end_move (GtkWidget *widget, GdkEventButton *bevent)
 			g_source_remove (panel_dragged_timeout);
 		panel_dragged_timeout = 0;
 		panel_been_moved = FALSE;
-		if (pointer_in_widget (basep->panel, bevent) &&
-		    ! gtk_widget_is_focus (basep->panel))
-			panel_widget_focus (PANEL_WIDGET (basep->panel));
 
 		/* FIXME: why is this neccessary!!!!???? */
 		gtk_container_foreach (GTK_CONTAINER (basep->panel),
@@ -829,6 +803,9 @@ panel_event(GtkWidget *widget, GdkEvent *event)
 	PanelWidget *panel = NULL;
 	BasePWidget *basep = NULL;
 	GdkEventButton *bevent;
+	GdkEventKey *kevent;
+	GdkEventFocus *fevent;
+	GtkStateType state;
 	int x, y;
 
 	if (BASEP_IS_WIDGET (widget)) {
@@ -884,7 +861,19 @@ panel_event(GtkWidget *widget, GdkEvent *event)
 			}
 		}
 		break;
-
+	case GDK_KEY_PRESS:
+		kevent = (GdkEventKey *)event;
+		if (GTK_IS_SOCKET (GTK_WINDOW (widget)->focus_widget)) {
+			/*
+		  	 * If the focus widget is a GtkSocket, i.e. the
+			 * focus is in an applet in another process, then key 
+			 * bindings do not work. We get around this by
+			 * activating the key binding we require here.
+			 */ 
+			if (kevent->keyval == GDK_F10 && kevent->state == GDK_CONTROL_MASK)
+				return gtk_bindings_activate (GTK_OBJECT (panel), kevent->keyval, kevent->state);
+		}
+		break;
 	default:
 		break;
 	}
@@ -1278,9 +1267,7 @@ drop_internal_applet (PanelWidget *panel, int pos, const char *applet_type,
 	} else if(strcmp(applet_type,"LAUNCHER:ASK")==0) {
 		ask_about_launcher(NULL, panel, pos, TRUE);
 
-	} else if(strcmp(applet_type,"STATUS:TRY")==0) {
-		load_status_applet(panel, pos, TRUE, NULL);
-	} 
+	}
 
 	if (remove_applet &&
 	    action == GDK_ACTION_MOVE) {
@@ -1829,28 +1816,6 @@ panel_data_by_id (const char *id)
 	return NULL;
 }
 
-void
-status_unparent (GtkWidget *widget)
-{
-	GList *li;
-	PanelWidget *panel = NULL;
-	if (BASEP_IS_WIDGET (widget))
-		panel = PANEL_WIDGET(BASEP_WIDGET(widget)->panel);
-	else if (FOOBAR_IS_WIDGET (widget))
-		panel = PANEL_WIDGET (FOOBAR_WIDGET (widget)->panel);
-	for(li=panel->applet_list;li;li=li->next) {
-		AppletData *ad = li->data;
-		AppletInfo *info = g_object_get_data (G_OBJECT (ad->applet),
-						      "applet_info");
-		if(info->type == APPLET_STATUS) {
-			status_applet_put_offscreen(info->data);
-		} else if(info->type == APPLET_DRAWER) {
-			Drawer *dr = info->data;
-			status_unparent(dr->drawer);
-		}
-	}
-}
-
 void
 panel_load_global_config (void)
 {
@@ -1858,9 +1823,11 @@ panel_load_global_config (void)
 
 	list = panel_gconf_all_global_entries ();
 
-	for (li = list; li != NULL ; li = li->next) {
-		panel_global_config_set_entry (li->data);
-		gconf_entry_free (li->data);
+	for (li = list; li != NULL; li = li->next) {
+		GConfEntry *entry = li->data;
+		li->data = NULL;
+		panel_global_config_set_entry (entry);
+		gconf_entry_free (entry);
 	}
 
 	g_slist_free (list);
@@ -2045,7 +2012,7 @@ panel_set_bool (const char *profile,
 void
 panel_load_panels_from_gconf (void)
 {
-	GSList     *panels;
+	GSList     *panel_ids;
 	GSList     *l;
 	const char *profile;
 	const char *key;
@@ -2054,10 +2021,10 @@ panel_load_panels_from_gconf (void)
 	
 	key = panel_gconf_general_key (profile, "panel_id_list");
 
-	panels = gconf_client_get_list (
+	panel_ids = gconf_client_get_list (
 			panel_gconf_get_client (), key, GCONF_VALUE_STRING, NULL);
 
-	for (l = panels; l; l = l->next) {
+	for (l = panel_ids; l; l = l->next) {
 		GtkWidget     *panel;
 		PanelType      type;
 		PanelBackType  back_type;
@@ -2287,7 +2254,7 @@ panel_load_panels_from_gconf (void)
 	}
 
 	/* Failsafe! */
-	if (!panels) {
+	if (panel_ids == NULL) {
 		GtkWidget *panel;
 
 		panel_error_dialog ("no_panels_found",
@@ -2300,7 +2267,7 @@ panel_load_panels_from_gconf (void)
 		gtk_widget_show (panel);
 	}
 
-	panel_g_slist_deep_free (panels);
+	panel_g_slist_deep_free (panel_ids);
 }
 
 void
@@ -2333,7 +2300,7 @@ panel_save_to_gconf (PanelData *pd)
 				client, key, GCONF_VALUE_STRING, NULL);
 
 	for (l = panel_id_list; l; l = l->next)
-		if (!strcmp (panel->unique_id, l->data))
+		if (strcmp (panel->unique_id, l->data) == 0)
 			break;
 	
 	if (!l) {
@@ -2350,7 +2317,7 @@ panel_save_to_gconf (PanelData *pd)
 	panel_set_string (profile, panel->unique_id, "panel_type", 
 			  gconf_enum_to_string (panel_type_type_enum_map, pd->type));
 
-	if (basep) {
+	if (basep != NULL) {
 		panel_set_bool (profile, panel->unique_id,
 				"hide_buttons_enabled",
 				basep->hidebuttons_enabled);
@@ -2455,16 +2422,18 @@ panel_remove_from_gconf (PanelWidget *panel)
 {
 	const char *key;
 	GSList     *new_panels = NULL;
-	GSList     *panels;
+	GSList     *panel_ids;
 	GSList     *l;
 
 	key = panel_gconf_general_key (panel_gconf_get_profile (), "panel_id_list");
 
-	panels = gconf_client_get_list (
+	panel_ids = gconf_client_get_list (
 			panel_gconf_get_client (), key, GCONF_VALUE_STRING, NULL);
 
-	for (l = panels; l; l = l->next) {
-		if (!strcmp (panel->unique_id, (char *) l->data)) {
+	for (l = panel_ids; l; l = l->next) {
+		char *id = l->data;
+		l->data = NULL;
+		if (strcmp (panel->unique_id, id) == 0) {
 			char *dir;
 
 			dir = g_strdup_printf ("/apps/panel/profiles/%s/panels/%s",
@@ -2473,12 +2442,13 @@ panel_remove_from_gconf (PanelWidget *panel)
 
 			panel_gconf_clean_dir (panel_gconf_get_client (), dir);
 			g_free (dir);
-			g_free (l->data);
-		} else
-			new_panels = g_slist_prepend (new_panels, l->data);
+			g_free (id);
+		} else {
+			new_panels = g_slist_prepend (new_panels, id);
+		}
         }
 
-	g_slist_free (panels);
+	g_slist_free (panel_ids);
 
         gconf_client_set_list (panel_gconf_get_client (), key,
 			       GCONF_VALUE_STRING, new_panels, NULL);
